Learn R Programming

mikropml (version 1.7.0)

check_training_frac: Check that the training fraction is greater than 0 and less than or equal to 1

Description

Check that the training fraction is greater than 0 and less than or equal to 1

Usage

check_training_frac(frac)

Arguments

frac

fraction (numeric)

Author

Kelly Sovacool, sovacool@umich.edu

Examples

Run this code
if (FALSE) {
check_training_frac(0.8)
}

Run the code above in your browser using DataLab