otu_mini_bin: Mini OTU abundance dataset

otu_mini_binR Documentation

Mini OTU abundance dataset

Description

A dataset containing relatives abundances of OTUs for human stool samples with a binary outcome, dx. This is a subset of otu_small.

Usage

otu_mini_bin

Format

A data frame The dx column is the diagnosis: healthy or cancerous (colorectal). All other columns are OTU relative abundances.


mikropml documentation built on Aug. 29, 2026, 1:06 a.m.