otu_mini_cont_results_nocv: Results from running the pipeline with glmnet on otu_mini_bin with Otu00001
as the outcome column,
using a custom train control scheme that does not perform cross-validation
Description
Results from running the pipeline with glmnet on otu_mini_bin with Otu00001
as the outcome column,
using a custom train control scheme that does not perform cross-validation
Usage
otu_mini_cont_results_nocv
Format
An object of class list of length 4.