Identify correlated features
get_corr_feats(
features,
corr_thresh = 1,
group_neg_corr = TRUE,
corr_method = "spearman"
)Dataframe of correlated features where the columns are feature1, feature2, and the correlation between those two features (anything exceeding corr_thresh).
a dataframe with each column as a feature for ML
For feature importance, group correlations
above or equal to corr_thresh (range 0 to 1; default: 1).
Whether to group negatively correlated features together (e.g. c(0,1) and c(1,0)).
correlation method. options or the same as those supported
by stats::cor: spearman, pearson, kendall. (default: spearman)
Begüm Topçuoğlu, topcuoglu.begum@gmail.com
Zena Lapp, zenalapp@umich.edu