otu_mini_cont_results_glmnet: Results from running the pipeline with glmnet on otu_mini_bin with Otu00001
as the outcome
Description
Results from running the pipeline with glmnet on otu_mini_bin with Otu00001
as the outcome
Usage
otu_mini_cont_results_glmnet
Format
An object of class list of length 4.